import {Cache} from "../cache";

export interface CachedPlayer extends Player {
  /**
   * The cache information.
   */
  cache: Cache;
}

type Player = {
  /**
   * The player's unique id.
   */
  uniqueId: string;

  /**
   * The player's trimmed unique id.
   */
  trimmedUniqueId: string;

  /**
   * The player's username.
   */
  username: string;

  /**
   * The player's skin.
   */
  skin: Skin;

  /**
   * The player's cape.
   */
  cape: Cape;
};

type Skin = {
  /**
   * The url of the skin.
   */
  url: string;

  /**
   * The model of the skin.
   */
  model: Model;

  /**
   * Whether this skin uses the
   * legacy skin format.
   */
  legacy: boolean;

  /**
   * The parts of the skin.
   */
  parts: Record<SkinPart, string>;
};

export enum SkinPart {
  HEAD = "head",
  FACE = "face",
  BODY = "body",
}

enum Model {
  DEFAULT,
  SLIM,
}

type Cape = {
  /**
   * The url of the cape.
   */
  url: string;
};
