import {MinecraftServer} from "../server";
import {Cache} from "../../cache";

export interface CachedBedrockMinecraftServer extends BedrockMinecraftServer {
  /**
   * The cache information.
   */
  cache: Cache;
}

interface BedrockMinecraftServer extends MinecraftServer {
  /**
   * The edition of the server.
   */
  edition: Edition;

  /**
   * The version of the server.
   */
  version: Version;

  /**
   * The gamemode of the server.
   */
  gamemode: Gamemode;
}

enum Edition {
  /**
   * Minecraft: Pocket Edition.
   */
  MCPE,

  /**
   * Minecraft: Education Edition.
   */
  MCEE,
}

type Version = {
  /**
   * The protocol version of the server.
   */
  protocol: number;

  /**
   * The version name of the server.
   */
  name: string;
};

type Gamemode = {
  /**
   * The name of the gamemode.
   */
  name: string;

  /**
   * The numeric ID of the gamemode.
   */
  numericId: number;
};
