import {MinecraftServer} from "../server";
import {Cache} from "../../cache";

export interface CachedJavaMinecraftServer extends JavaMinecraftServer {
  /**
   * The cache information.
   */
  cache: Cache;
}

interface JavaMinecraftServer extends MinecraftServer {
  /**
   * The version of the server.
   */
  version: Version;

  /**
   * The favicon of the server.
   */
  favicon: Favicon;

  /**
   * Whether the server prevents chat reports.
   */
  preventsChatReports: boolean;

  /**
   * Whether the server enforces secure chat.
   */
  enforcesSecureChat: boolean;

  /**
   * Whether the server has previews chat enabled.
   */
  previewsChat: boolean;

  /**
   * The mojang blocked status for the server.
   */
  mojangBlocked: boolean;
}

type Favicon = {
  /**
   * The base64 encoded favicon.
   */
  base64: string;

  /**
   * The URL to the favicon.
   */
  url: string;
};

type Version = {
  /**
   * The version name of the server.
   */
  name: string;

  /**
   * The server's platform.
   */
  platform: string;

  /**
   * The protocol version of the server.
   */
  protocol: number;

  /**
   * The protocol name of the server.
   */
  protocolName: string;
};
