export type MinecraftServer = {
  /**
   * The hostname of the server.
   */
  hostname: string;

  /**
   * The ip of the server.
   */
  ip: string;

  /**
   * The port of the server.
   */
  port: number;

  /**
   * The DNS records for the server.
   */
  records: [];

  /**
   * The MOTD of the server.
   */
  motd: Motd;

  /**
   * The players on the server.
   */
  players: Players;

  /**
   * The location of the server, or undefined if the location is unknown.
   */
  location?: GeoLocation;
};

type Motd = {
  /**
   * The raw MOTD.
   */
  raw: string[];

  /**
   * The clean MOTD, without any colors.
   */
  clean: string[];

  /**
   * The HTML MOTD, with HTML tags for colors.
   */
  html: string[];

  /**
   * The server list MOTD preview.
   */
  preview: string;
};

type Players = {
  /**
   * The max players allowed on the server.
   */
  max: number;

  /**
   * The online players on the server.
   */
  online: number;

  /**
   * The list of players on the server.
   */
  sample: PlayerSample[];
};

type PlayerSample = {
  /**
   * The UUID of the player.
   */
  id: string;

  /**
   * The name of the player.
   */
  name: string;
};

type GeoLocation = {
    /**
     * The country of the location.
     */
    country: string;

    /**
     * The region of the location.
     */
    region: string;

    /**
     * The city of the location.
     */
    city: string;

    /**
     * The latitude of the location.
     */
    latitude: number;

    /**
     * The longitude of the location.
     */
    longitude: number;
}
